@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply arpeggiation patterns to groups of notes
 
-our $VERSION = '0.0301';
+our $VERSION = '0.0302';
 
 use Moo;
 use strictures 2;
@@ -113,7 +113,7 @@ Music::MelodicDevice::Arpeggiation - Apply arpeggiation patterns to groups of no
 
 =head1 VERSION
 
-version 0.0301
+version 0.0302
 
 =head1 SYNOPSIS
 
@@ -121,14 +121,18 @@ version 0.0301
 
   my $arp = Music::MelodicDevice::Arpeggiation->new;
 
-  $arp->arp_type('my_type', sub { my ($notes); return [0,2,1] }); # set a new type
+  # set a new pattern type
+  $arp->arp_type('my_type', sub { my ($notes); return [0,2,1] });
 
-  my $arped = $arp->arp([60,64,67], 1, 'updown', 3);
+  # arpeggiate the 'updown' pattern
+  my $arped = $arp->arp(['C4','E4','G4'], 1, 'updown');
+  # [['d24', 'C4'],['d24', 'E4'],['d24', 'G4'],['d24', 'E4']]
+  $arped = $arp->arp([60,64,67], 1, 'updown', 3); # midinums repeated 3 times
 
 =head1 DESCRIPTION
 
 C<Music::MelodicDevice::Arpeggiation> applies arpeggiation patterns to
-groups of notes.
+groups of notes that can be used with MIDI-Perl.
 
 =head1 ATTRIBUTES
 
@@ -197,7 +201,10 @@ Create a new C<Music::MelodicDevice::Arpeggiation> object.
   $notes = $arp->arp(\@pitches, $duration, $type);
   $notes = $arp->arp(\@pitches, $duration, $type, $repeats);
 
-Return a list of lists of C<d#> MIDI-Perl strings with the pitches indexed by the arpeggiated pattern built from the given C<type>. These MIDI-Perl duration strings are distributed evenly across the given C<duration>.
+Return a list of lists of C<d#> MIDI-Perl strings with the pitches
+indexed by the arpeggiated pattern built from the given C<type>. These
+MIDI-Perl duration strings are distributed evenly across the given
+C<duration>.
 
 =head2 arp_type
 
